(* ::Package:: *)

BeginPackage["CAN`"];
CanOuvrir::usage = "CanOuvrir[nom] nom : SysamSP5 ou SysamPCI"
CanFermer::usage = "CanFermer[]"
CanConfigEntrees::usage = "CanConfigEntrees[listeVoies, listeCalibres]"
CanConfigTrigger::usage = "CanConfigTrigger[voie,seuil]"
CanConfigTriggerExterne::usage = "CanConfigTriggerExterne[seuil]"
CanConfigEchantillon::usage = "CanConfigEchantillon[temps,nbpoints] temps : pas d'\[CapitalATilde]\[Copyright]chantillonnage en microsecondes, nbpoints : nombre de points"
CanAcquerir::usage = "CanAcquerir[]"
CanAcquerirAvecSorties::usage = "CanAcquerirAvecSorties[valeurs1,valeurs2]"
CanEntrees::usage = "CanEntrees[]"
CanTemps::usage = "CanTemps[]"
CanConfigSortie::usage = "CanConfigSortie[nsortie,te,listeValeurs,repetition]"
CanDeclencherSorties::usage = "CanDeclencherSortie[s1,s2]"
CanStopperSorties::usage = "CanStopperSorties[s1,s2]"
CanActiverLecture::usage = "CanActiverLecture[listeVoies]"
CanDesactiverLecture::usage = "CanDesactiverLecture[]"
CanLire::usage = "CanLire[]"
CanEcrire::usage = "CanEcrire[s1,tension1,s2,tension2]"
CanLancer::usage = "CanLancer[]"
CanLancerAvecSorties::usage = "CanLancerAvecSorties[listeValeurs1,listeValeurs2]"
CanPaquet::usage = "CanPaquet[premier]"

Options[CanConfigEntrees]={VoiesDifferentielles->{}}
Options[CanConfigTrigger]={Montant->1,Pretrigger->1,PretriggerSouple->1,Hysteresis->1}
Options[CanConfigTriggerExterne]={Pretrigger->1,PretriggerSouple->1,Seuil->0.0}
Options[CanActiverLecture]={Latch->0}

CANDIRECTORY = $BaseDirectory<>"/Applications/CAN/"

CanOuvrir[nom_]:=Module[{r},
    Install[CANDIRECTORY<>"sysam.exe"];
    r=iCanOuvrir[nom];
    If[r==1,Return,Print[r]; Abort[]];
]
CanFermer[]:=(iCanFermer[]; Uninstall[CANDIRECTORY<>"sysam.exe"]);

CanConfigEntrees[voies_,calibres_,opts___]:=Module[{r},
    r=iCanConfigEntrees[voies,1.0*calibres,VoiesDifferentielles/.{opts}/.Options[CanConfigEntrees]];
    If[r==1,Return,Print[r]; Abort[]];
]

CanConfigTrigger[voie_,seuil_,opts___]:=Module[{r},
    r = iCanConfigTrigger[0,voie,1.0*seuil,Montant/.{opts}/.Options[CanConfigTrigger],Pretrigger/.{opts}/.Options[CanConfigTrigger],PretriggerSouple/.{opts}/.Options[CanConfigTrigger],Hysteresis/.{opts}/.Options[CanConfigTrigger]];
    If[r==1,Return,Print[r]; Abort[]];
]

CanConfigTriggerExterne[opts___]:=Module[{r},
    r = iCanConfigTrigger[1,0,Seuil/.{opts}/.Options[CanConfigTriggerExterne],1,Pretrigger/.{opts}/.Options[CanConfigTriggerExterne],PretriggerSouple/.{opts}/.Options[CanConfigTriggerExterne],0];
    If[r==1,Return,Print[r]; Abort[]];
]
CanDesactiverTrigger[]:=Module[{r},
    r = iCanConfigTrigger[0,-1,0,0,0,0,0];
    If[r==1,Return,Print[r]; Abort[]];
]
CanConfigEchantillon[temps_,nbpoints_]:=Module[{r},
    r = iCanConfigEchantillon[1.0*temps,nbpoints];
    If[r==1,Return,Print[r]; Abort[]];
]
CanAcquerir[]:=Module[{r},
    r = iCanAcquerir[];
    If[r==1,Return,Print[r]; Abort[]];
]
CanLancer[]:=Module[{r},
    r = iCanLancer[];
    If[r==1,Return,Print[r]; Abort[]];
]
CanAcquerirAvecSorties[listeValeurs1_,listeValeurs2_]:=Module[{r},
    r = iCanAcquerirAvecSorties[listeValeurs1,listeValeurs2];
    If[r==1,Return,Print[r]; Abort[]];
]
CanLancerAvecSorties[listeValeurs1_,listeValeurs2_]:=Module[{r},
    r = iLancerAvecSorties[listeValeurs1,listeValeurs2];
    If[r==1,Return,Print[r]; Abort[]];
]
CanConfigSortie[nsortie_,te_,listeValeurs_,repetition_]:=Module[{r},
    r = iCanConfigSortie[nsortie,1.0*te,listeValeurs,repetition];
    If[r==1,Return,Print[r]; Abort[]];
]
CanDeclencherSorties[s1_,s2_]:=Module[{r},
    r = iCanDeclencherSorties[s1,s2];
    If[r==1,Return,Print[r]; Abort[]];
]
CanStopperSorties[s1_,s2_]:=Module[{r},
    r = iCanStopperSorties[s1,s2];
    If[r==1,Return,Print[r]; Abort[]];
]

CanActiverLecture[listeVoies_,opts___]:=Module[{r},
    r = iCanActiverLecture[listeVoies,Latch/.{opts}/.Options[CanActiverLecture]];
    If[r==1,Return,Print[r]; Abort[]];
]
CanDesactiverLecture[]:=Module[{r},
    r = iCanDesactiverLecture[];
    If[r==1,Return,Print[r]; Abort[]];
]
CanLire[]:=Module[{r},
    r = iCanLire[];
    If[Length[r]>0,Return[r],Print[r];Abort[]];
]
CanEcrire[s1_,tension1_,s2_,tension2_]:=Module[{r},
    r = iCanEcrire[s1,1.0*tension1,s2,1.0*tension2];
    If[r==1,Return,Print[r]; Abort[]];
]

EndPackage[];
